<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Správa vyjímatelných médií/zařízení</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Nastavení vyjímatelných médií</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Chování</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="26"/>
        <source>When a device is connected:</source>
        <translation>Když je zařízení připojeno:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>Zobrazit vyskakovací nabídku</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>Ukázat informace</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>Nedělat nic</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je připojeno.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Zařízení &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; je odebráno.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Správa vyjímatelných médií/zařízení</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>Připojení &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; se nezdařilo: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="157"/>
        <location filename="../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>Správa vyjímatelných médií/zařízení</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Odpojení &lt;strong&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/strong&gt; se nezdařilo: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Nejsou k dispozici žádná zařízení</translation>
    </message>
</context>
</TS>
